@@ -299,9 +299,46 @@ class TestRecipe(unittest.TestCase):
     @mock.patch(Recipe, 'install_release')
     @mock.patch(Recipe, 'create_manage_script')
     @mock.patch(Recipe, 'create_test_runner')
+    @mock.patch('zc.recipe.egg', 'Develop')
+    def test_fulfills_django_dependency(self, rmtree, path_exists,
+        urlretrieve, copytree, working_set, scripts, install_release,
+        manage, testrunner, develop):
+        # Test for https://bugs.launchpad.net/djangorecipe/+bug/397864
+        # djangorecipe should always fulfil the 'Django' requirement.
+        self.recipe.options['version'] = '1.0'
+        path_exists.return_value = True
+        working_set.return_value = (None, [])
+        manage.return_value = []
+        scripts.return_value = []
+        testrunner.return_value = []
+        develop_install = mock.Mock()
+        develop.return_value = develop_install
+        self.recipe.install()
+
+        # We should see that Django was added as a develop egg.
+        options = develop.call_args[0][2]
+        self.assertEqual(options['location'], os.path.join(self.parts_dir, 'django'))
+
+        # Check that the install() method for the develop egg was called with no args
+        first_method_name, args, kwargs = develop_install.method_calls[0]
+        self.assertEqual('install', first_method_name)
+        self.assertEqual(0, len(args))
+        self.assertEqual(0, len(kwargs))
+
+    @mock.patch('shutil', 'rmtree')
+    @mock.patch('os.path', 'exists')
+    @mock.patch('urllib', 'urlretrieve')
+    @mock.patch('shutil', 'copytree')
+    @mock.patch(ZCRecipeEggScripts, 'working_set')
+    @mock.patch('zc.buildout.easy_install', 'scripts')
+    @mock.patch(Recipe, 'install_release')
+    @mock.patch(Recipe, 'create_manage_script')
+    @mock.patch(Recipe, 'create_test_runner')
+    @mock.patch('zc.recipe.egg', 'Develop')
     def test_extra_paths(self, rmtree, path_exists, urlretrieve,
                                    copytree, working_set, scripts,
-                                   install_release, manage, testrunner):
+                                   install_release, manage, testrunner,
+                                   develop):
         # The recipe allows extra-paths to be specified. It uses these to
         # extend the Python path within it's generated scripts.
         self.recipe.options['version'] = '1.0'
@@ -311,6 +348,7 @@ class TestRecipe(unittest.TestCase):
         manage.return_value = []
         scripts.return_value = []
         testrunner.return_value = []
+        develop.return_value = mock.Mock()
         self.recipe.install()
         self.assertEqual(manage.call_args[0][0][-2:],
                          ['somepackage', 'anotherpackage'])
@@ -325,9 +363,11 @@ class TestRecipe(unittest.TestCase):
     @mock.patch(Recipe, 'create_manage_script')
     @mock.patch(Recipe, 'create_test_runner')
     @mock.patch('site', 'addsitedir')
+    @mock.patch('zc.recipe.egg', 'Develop')
     def test_pth_files(self, rmtree, path_exists, urlretrieve,
                        copytree, working_set, scripts,
-                       install_release, manage, testrunner, addsitedir):
+                       install_release, manage, testrunner, addsitedir,
+                       develop):
         # When a pth-files option is set the recipe will use that to add more
         # paths to extra-paths.
         self.recipe.options['version'] = '1.0'
@@ -336,6 +376,8 @@ class TestRecipe(unittest.TestCase):
         scripts.return_value = []
         manage.return_value = []
         testrunner.return_value = []
+        develop.return_value = mock.Mock()
+
         # The mock values needed to demonstrate the pth-files option.
         addsitedir.return_value = ['extra', 'dirs']
         self.recipe.options['pth-files'] = 'somedir'
@@ -543,9 +585,10 @@ class TestRecipe(unittest.TestCase):
     @mock.patch(ZCRecipeEggScripts, 'working_set')
     @mock.patch('zc.buildout.easy_install', 'scripts')
     @mock.patch(Recipe, 'install_release')
+    @mock.patch('zc.recipe.egg', 'Develop')
     def test_clear_existing_django(self, rmtree, path_exists, urlretrieve,
                                    copytree, working_set, scripts,
-                                   install_release):
+                                   install_release, develop):
         # When the recipe is executed and Django is already installed
         # within parts it should remove it. We will mock the exists
         # check to make it let the recipe think it has an existing
@@ -554,6 +597,7 @@ class TestRecipe(unittest.TestCase):
         path_exists.return_value = True
         working_set.return_value = (None, [])
         scripts.return_value = []
+        develop.return_value = mock.Mock()
         self.recipe.install()
         # This should have called remove tree
         self.assert_(rmtree.called)
